/*
 * blinker.c
 *
 * driver for TIRSLK LED blinkers
 * P8.4 Yellow front right LED
 * P8.5 Yellow front left LED
 * P8.6 Red back right LED
 * P8.7 Red back left LED
 */
/* This example accompanies the books
   "Embedded Systems: Introduction to the MSP432 Microcontroller",
       ISBN: 978-1512185676, Jonathan Valvano, copyright (c) 2017
   "Embedded Systems: Real-Time Interfacing to the MSP432 Microcontroller",
       ISBN: 978-1514676585, Jonathan Valvano, copyright (c) 2017
   "Embedded Systems: Real-Time Operating Systems for ARM Cortex-M Microcontrollers",
       ISBN: 978-1466468863, , Jonathan Valvano, copyright (c) 2017
 For more information about my classes, my research, and my books, see
 http://users.ece.utexas.edu/~valvano/

Simplified BSD License (FreeBSD License)
Copyright (c) 2017, Jonathan Valvano, All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.
2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are
those of the authors and should not be interpreted as representing official
policies, either expressed or implied, of the FreeBSD Project.
*/
#include <stdint.h>
#include "msp.h"
#include "../inc/Nokia5110.h"
// ------------Blinker_Init------------
// Initialize four LED blinkers on TIRSLK
// Input: none
// Output: none
void Blinker_Init(void){
  P8->SEL0 &= ~0xF0;
  P8->SEL1 &= ~0xF0;    // configure P8.4-P8.7 as GPIO
  P8->DIR |= 0xF0;      // make P8.4-P8.7 out
  P8->OUT &= ~0xF0;     // all LEDs off
}
#define FR_RGHT 0x10
#define FR_LEFT 0x20
#define BK_RGHT 0x40
#define BK_LEFT 0x80

//------------Blinker_Output------------
// Output to four LED blinkers on TIRSLK
// Input: data to write to LEDs (uses bits 7-4)
//   bit 4 Yellow front right LED
//   bit 5 Yellow front left LED
//   bit 6 Red back right LED
//   bit 7 Red back left LED
// Output: none
void Blinker_Output(uint8_t data){  // write four outputs bits of P8
  P8->OUT = (P8->OUT&0x0F)|data;
}

void Nokia5110_OutHex7(uint8_t n){
  n = n&0x0F;
  if(n>9){
    Nokia5110_OutChar('A'+n-10);
  }else{
    Nokia5110_OutChar(n+'0');        /* ones digit */
  }
}
void Nokia5110_OutUHex7(uint8_t n){
  Nokia5110_OutString(" 0x");
  Nokia5110_OutHex7(n/16); /* 16s digit */
  Nokia5110_OutHex7(n);    /* ones digit */
}

void Nokia5110_OutUDec16(uint32_t n){
  Nokia5110_OutChar(' ');
  if(n>=100){
    Nokia5110_OutChar(n/100+'0'); /* 100 digit */
    n = n%100;
    Nokia5110_OutChar(n/10+'0'); /* 10 digit */
    Nokia5110_OutChar(n%10+'0'); /* ones digit */
  }else{
    Nokia5110_OutChar(' ');
    if(n>=10){
      Nokia5110_OutChar(n/10+'0'); /* 10 digit */
      Nokia5110_OutChar(n%10+'0'); /* ones digit */
    }else{
      Nokia5110_OutChar(' ');
      Nokia5110_OutChar(n+'0'); /* ones digit */
    }
  }
}
void Nokia5110_OutUDec2(uint32_t n){
  if(n>=100){
    Nokia5110_OutChar(' ');  /* 100 digit */
    Nokia5110_OutChar('*'); /* illegal */
  }else{
    if(n>=10){
      Nokia5110_OutChar(n/10+'0'); /* 10 digit */
      Nokia5110_OutChar(n%10+'0'); /* ones digit */
    }else{
      Nokia5110_OutChar(' ');
      Nokia5110_OutChar(n+'0'); /* ones digit */
    }
  }
}

